@@ -30,7 +30,9 @@ def url_to_module(url):
         'kankanews': bilibili,
         'ku6': ku6,
         'pptv': pptv,
+        'qq': qq,
         'sina': sina,
+        'smgbb': bilibili,
         'sohu': sohu,
         'tudou': tudou,
         'vimeo': vimeo,
